@@ -1,5 +1,6 @@
 import dash_mantine_components as dmc
 from dash_down.html_renderer import DashHtmlRenderer
+from dash import html
 
 
 class DmcRenderer(DashHtmlRenderer):
@@ -11,7 +12,8 @@ class DmcRenderer(DashHtmlRenderer):
         return text
 
     def paragraph(self, text):
-        return dmc.Text(text)
+        # TODO: Use both text and p? Or just one? Some CSS (e.g. github) need the p's.
+        return dmc.Text(html.P(text))
 
     def link(self, link, children=None, title=None):
         return dmc.Anchor(children, href=link)
@@ -20,7 +22,7 @@ class DmcRenderer(DashHtmlRenderer):
         return dmc.Image(src=src, alt=alt, caption=title)
 
     def heading(self, children, level):
-        return dmc.Title(children, order=level)
+        return dmc.Title(super().add_header_anchor(children), order=level)
 
     def thematic_break(self):
         return dmc.Divider()
@@ -46,4 +48,4 @@ class DmcRenderer(DashHtmlRenderer):
         return dmc.ListItem(text)
 
     def table(self, text):
-        return dmc.Table(text, striped=True, highlightOnHover=True)
\ No newline at end of file
+        return dmc.Table(text, striped=True, highlightOnHover=True)
